@@ -4,7 +4,9 @@ echo "" 												>> $EXTENSION/build_order.txt
 	
 # Required
 [[ $(command -v cmake) == "" ]] && echo "Installing cmake" && extension --install cmake && echo "Finished cmake"
-[ ! -d /usr/share/cmake/SPIRV-Headers ] && echo "Installing spirv_headers" && extension --install spirv_headers && echo "Finished spirv_headers"
+if [ $(cat /etc/extension/installed_version.list | grep spirv_headers | cut -d \= -f 2) != "1.4.321.0" ]; then 
+	echo "Installing spirv_headers" && extension --install spirv_headers:1.4.321.0 && echo "Finished spirv_headers"
+fi
 
 if [ $BUILD_ALL == "false" ] && [[ $(command -v spirv-lint) == "" ]]; then
 	echo "spirv_tools" 									>> $EXTENSION/build_order.txt
